@@ -34,6 +34,9 @@ sub load_source{
         ($title) = $pod =~ m{ =head1 \s+ (.*) }x;
         $title = '' if !defined $title;
     }
+    elsif ( $options->{title} and $options->{title} ne 'pod' ) {
+        $title = $options->{title};
+    }
 
     return { pod => $pod, filename => $filename, title => $title };
 }
@@ -50,7 +53,7 @@ EPublisher::Source::Plugin::File - File source plugin
 
 =head1 VERSION
 
-version 0.41
+version 0.5
 
 =head1 SYNOPSIS
 
